=======
Strings
=======

The following methods are available under the `expr.str` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.str.concat
    Expr.str.contains
    Expr.str.count_match
    Expr.str.decode
    Expr.str.encode
    Expr.str.ends_with
    Expr.str.explode
    Expr.str.extract
    Expr.str.extract_all
    Expr.str.json_extract
    Expr.str.json_path_match
    Expr.str.lengths
    Expr.str.ljust
    Expr.str.lstrip
    Expr.str.n_chars
    Expr.str.replace
    Expr.str.replace_all
    Expr.str.rjust
    Expr.str.rstrip
    Expr.str.slice
    Expr.str.split
    Expr.str.split_exact
    Expr.str.splitn
    Expr.str.starts_with
    Expr.str.strip
    Expr.str.strptime
    Expr.str.to_lowercase
    Expr.str.to_uppercase
    Expr.str.zfill
    Expr.str.parse_int
